structure(
  list(
    url = "content/01234567/__thumbnail__",
    status_code = 404L,
    content = charToRaw("404 page not found")
  ),
  class = "response"
)
